Package: scatterbar
Title: Scattered Stacked Bar Chart Plots
Type: Package
Version: 0.1.0
Imports: magrittr, dplyr, tidyr, ggplot2
Authors@R: 
    c(person("Dee", "Velazquez", email = "dvelazq5@jhu.edu", 
    role = c("aut", "cre"), 
    comment = c(ORCID = "0009-0004-4380-4794")),
    person("Jean", "Fan", email = "jeanfan@jhu.edu", 
    role = c("aut", "rev"), 
    comment = c(ORCID = "0000-0002-0212-5451")))
URL: https://github.com/JEFworks-Lab/scatterbar,
        http://jef.works/scatterbar/
BugReports: https://github.com/JEFworks-Lab/scatterbar/issues
Description: Provides a powerful and flexible tool for visualizing proportional data across spatially resolved contexts. By combining the concepts of scatter plots and stacked bar charts, 'scatterbar' allows users to create scattered bar chart plots, which effectively display the proportions of different categories at each (x, y) location. This visualization is particularly useful for applications where understanding the distribution of categories across spatial coordinates is essential. This package features automatic determination of optimal scaling factors based on data, customizable scaling and padding options for both x and y axes, flexibility to specify custom colors for each category, options to customize the legend title, and integration with 'ggplot2' for robust and high-quality visualizations. For more details, see Velazquez et al. (2024) <doi:10.1101/2024.08.14.606810>.
License: GPL-3
Encoding: UTF-8
LazyData: FALSE
RoxygenNote: 7.3.2
Depends: R (>= 3.5.0)
Suggests: knitr, rmarkdown, patchwork
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-11-22 22:47:37 UTC; deev
Author: Dee Velazquez [aut, cre] (<https://orcid.org/0009-0004-4380-4794>),
  Jean Fan [aut, rev] (<https://orcid.org/0000-0002-0212-5451>)
Maintainer: Dee Velazquez <dvelazq5@jhu.edu>
Repository: CRAN
Date/Publication: 2024-11-25 11:50:02 UTC
Built: R 4.6.0; ; 2026-04-30 03:04:42 UTC; unix
